pub fn trimm_array4<T>(
array: &Array4<T>,
overlap_size: usize,
) -> ArrayView4<'_, T>Expand description
Trims the overlap border from a 4D array. The memory layout of the output is not guaranteed.
pub fn trimm_array4<T>(
array: &Array4<T>,
overlap_size: usize,
) -> ArrayView4<'_, T>Trims the overlap border from a 4D array. The memory layout of the output is not guaranteed.