pub struct RasterBlock<U>where
U: RasterType,{
pub block_index: usize,
pub read_window: ReadWindow,
pub overlap_size: usize,
pub geo_transform: GeoTransform,
pub overlap: Overlap,
pub shape: RasterDataShape,
pub epsg_code: usize,
pub raster_metadata: RasterMetadata<U>,
}Expand description
A block representing a partition of a raster dataset for parallel processing.
Fields
block_index: usizeIndex of this block in the dataset
read_window: ReadWindowWindow describing which portion of the dataset this block covers
overlap_size: usizeSize of overlap with neighboring blocks
geo_transform: GeoTransformGeographic transformation parameters
overlap: OverlapOverlap data with neighboring blocks
shape: RasterDataShapeShape of the raster data
epsg_code: usizeEPSG coordinate reference system code
raster_metadata: RasterMetadata<U>Full raster metadata
Implementations
Sourceimpl<U> RasterBlock<U>where
U: RasterType,
impl<U> RasterBlock<U>where
U: RasterType,
Sourcepub fn into_frc(&self, data: &Array2<U>) -> Array3<U>
pub fn into_frc(&self, data: &Array2<U>) -> Array3<U>
Converts a 2D array into a 3D feature array.
Sourcepub fn write_samples_feature<T>(
&self,
data: &Array2<T>,
file_name: &PathBuf,
na: T,
)where
T: RasterType,
pub fn write_samples_feature<T>(
&self,
data: &Array2<T>,
file_name: &PathBuf,
na: T,
)where
T: RasterType,
Writes sample data to a vector file.
Sourcepub fn write3<T>(&self, data: Array3<T>, out_fn: &PathBuf)where
T: RasterType,
pub fn write3<T>(&self, data: Array3<T>, out_fn: &PathBuf)where
T: RasterType,
Writes 3D data to a file.
Sourcepub fn write_time_step_blocks<T>(
&self,
data: &Array4<T>,
tmp_file: &Path,
file_stem: &str,
bid: usize,
) -> Vec<PathBuf>where
T: RasterType,
pub fn write_time_step_blocks<T>(
&self,
data: &Array4<T>,
tmp_file: &Path,
file_stem: &str,
bid: usize,
) -> Vec<PathBuf>where
T: RasterType,
Writes each time step (axis 0) of a 4D array as a separate block file.
Replaces the duplicated loop pattern found in apply(), apply_with_mask()
and mosaic() in processing.rs.