Function compute_raster_union_extent

pub fn compute_raster_union_extent(
    files: &[PathBuf],
    target_epsg: u32,
) -> Result<Extent>
Compute the union extent of multiple raster files in the target CRS.

Each input’s four corners are reprojected to the target EPSG using GDAL’s CoordTransform API, then the bounding box of all transformed corners is returned.