Function compute_vector_extent

pub fn compute_vector_extent(
    vector_path: &Path,
    target_epsg: u32,
) -> Result<Extent>
Compute the extent of a vector layer in the target CRS.

Reads the layer extent and reprojects the four corners to the target EPSG using GDAL’s CoordTransform API.