Function mosaic

pub fn mosaic(
    collected: &[PathBuf],
    tmp_file: &Path,
    epsg_code: u32,
    extent: Option<Extent>,
    resolution: Option<f64>,
) -> Result<()>
Creates a mosaic from multiple raster files.

If extent is provided, each input is warped to that extent via -te. If resolution is provided, each input is resampled to that resolution via -tr.