Function mosaic_translate_cleanup_time_steps

pub fn mosaic_translate_cleanup_time_steps(
    collected: &[Vec<PathBuf>],
    out_file: &Path,
    epsg_code: u32,
    n_times: usize,
)
Assembles time-step block files into a final output via mosaic + translate + cleanup.

Variant for Vec<Vec<PathBuf>> where each inner vec corresponds to a time step.