pub(crate) fn warp_with_te_tr(
source: PathBuf,
target_te: &Extent,
target_resolution: ImageResolution,
) -> PathBufExpand description
Warps a raster source to a different extent and resolution.
pub(crate) fn warp_with_te_tr(
source: PathBuf,
target_te: &Extent,
target_resolution: ImageResolution,
) -> PathBufWarps a raster source to a different extent and resolution.