pub fn get_asset_href(
feature_collection: &ItemCollection,
date_time: &DateTime<FixedOffset>,
asset_name: &str,
) -> PathBufExpand description
Gets the asset href for a specific date and asset name from a STAC feature collection.
pub fn get_asset_href(
feature_collection: &ItemCollection,
date_time: &DateTime<FixedOffset>,
asset_name: &str,
) -> PathBufGets the asset href for a specific date and asset name from a STAC feature collection.