pub struct Overlap {
pub left: usize,
pub top: usize,
pub right: usize,
pub bottom: usize,
}Expand description
Overlap size for block-based operations (padding around each block).
Fields
left: usizeNumber of pixels to pad on the left side.
top: usizeNumber of pixels to pad on the top side.
right: usizeNumber of pixels to pad on the right side.
bottom: usizeNumber of pixels to pad on the bottom side.