pub struct Rectangle {
pub left: usize,
pub top: usize,
pub right: usize,
pub bottom: usize,
}Expand description
Rectangle for array indexing (distances from a center point).
Fields
left: usizeNumber of columns to the left of the center.
top: usizeNumber of rows above the center.
right: usizeNumber of columns to the right of the center.
bottom: usizeNumber of rows below the center.